@@ -1,6 +1,6 @@
 from . import WindowsPatch
 
-__version__ = '3.2.10'
+__version__ = '3.3.1'
 
 
 class PeekPlatformConfig:
@@ -30,3 +30,6 @@ class PeekPlatformConfig:
 
     # The instance of the PluginLoaderABC
     pluginLoader = None
+
+    # Is this a subprocess instance of a service.
+    isPluginSubprocess = False
