@@ -22,12 +22,9 @@ class PeekFileConfigHttpMixin:
     @property
     def sitePort(self) -> int:
         with self._config._cfg as c:
-            return c.httpServer[self._name].sitePort(self._defaultPort, require_integer)
-
-    @property
-    def enableHttps(self) -> int:
-        with self._config._cfg as c:
-            return c.httpServer[self._name].enableHttps(False, require_bool)
+            return c.httpServer[self._name].sitePort(
+                self._defaultPort, require_integer
+            )
 
     @property
     def redirectFromHttpPort(self) -> int:
@@ -35,10 +32,17 @@ class PeekFileConfigHttpMixin:
             return c.httpServer[self._name].redirectFromHttpPort(None)
 
     @property
-    def sslBundleFilePath(self) -> Optional[str]:
-        default = os.path.join(self._config._homePath, "peek-ssl-bundle.pem")
+    def useSsl(self) -> bool:
         with self._config._cfg as c:
-            file = c.httpServer[self._name].sslBundleFilePath(default, require_string)
+            return c.httpServer[self._name].useSsl(False, require_bool)
+
+    @property
+    def sslBundleFilePath(self) -> Optional[str]:
+        default = os.path.join(self._config._homePath, "key-cert-cachain.pem")
+        with self._config._cfg as c:
+            file = c.httpServer[self._name].sslBundleFilePath(
+                default, require_string
+            )
             if os.path.exists(file):
                 return file
             return None
