@@ -16,6 +16,15 @@ from jsoncfg.value_mappers import require_string
 from peek_platform import PeekPlatformConfig
 from twisted.internet.defer import inlineCallbacks
 
+from peek_platform.subproc_plugin_init.plugin_subproc.plugin_subproc_platform_config_tuple import (
+    PluginSubprocPlatformConfigTuple,
+)
+from peek_platform.subproc_plugin_init.plugin_subproc.plugin_subproc_vortex_msg_tuple import (
+    PluginSubprocVortexMsgTuple,
+)
+from peek_platform.subproc_plugin_init.plugin_subproc.plugin_subproc_vortex_payload_envelope_tuple import (
+    PluginSubprocVortexPayloadEnvelopeTuple,
+)
 from peek_plugin_base.PluginCommonEntryHookABC import PluginCommonEntryHookABC
 from peek_plugin_base.PluginPackageFileConfig import PluginPackageFileConfig
 from vortex.PayloadIO import PayloadIO
@@ -51,6 +60,9 @@ _DebounceArgsTuple()
 SimpleSubprocTaskResultTuple()
 SimpleSubprocTaskCallTuple()
 SimpleSubprocTaskConstructorTuple()
+PluginSubprocPlatformConfigTuple()
+PluginSubprocVortexMsgTuple()
+PluginSubprocVortexPayloadEnvelopeTuple()
 
 corePlugins = [
     "peek_core_email",
@@ -119,6 +131,9 @@ class PluginLoaderABC(metaclass=ABCMeta):
         # Until we implement dynamic loading and unloading of plugins
         # make sure we don't load them twice, because we don't yet
         # support it.
+
+        from peek_platform import PeekPlatformConfig
+
         if pluginName in self._loadedPlugins:
             raise Exception(
                 "Plugin %s is already loaded, check config.json" % pluginName
@@ -139,6 +154,7 @@ class PluginLoaderABC(metaclass=ABCMeta):
                 )
 
             PluginPackage = modSpec.loader.load_module()
+
             pluginRootDir = os.path.dirname(PluginPackage.__file__)
 
             # Load up the plugin package info
@@ -160,13 +176,23 @@ class PluginLoaderABC(metaclass=ABCMeta):
                 )
                 return
 
+            configForService = pluginPackageJson.configForService(
+                PeekPlatformConfig.componentName
+            )
+
             # Get the entry hook class from the package
             entryHookGetter = getattr(
                 PluginPackage, str(self._entryHookFuncName)
             )
-            EntryHookClass = entryHookGetter() if entryHookGetter else None
 
-            if not EntryHookClass:
+            runInSubprocess = (
+                configForService.standalone(False)
+                and not PeekPlatformConfig.isPluginSubprocess
+            )
+
+            RealEntryHookClass = entryHookGetter() if entryHookGetter else None
+
+            if not RealEntryHookClass:
                 logger.warning(
                     "Skipping load for %s, %s.%s is missing or returned None",
                     pluginName,
@@ -175,12 +201,22 @@ class PluginLoaderABC(metaclass=ABCMeta):
                 )
                 return
 
-            if not issubclass(EntryHookClass, self._entryHookClassType):
+            if not issubclass(RealEntryHookClass, self._entryHookClassType):
                 raise Exception(
                     "%s load error, Excpected %s, received %s"
-                    % (pluginName, self._entryHookClassType, EntryHookClass)
+                    % (pluginName, self._entryHookClassType, RealEntryHookClass)
                 )
 
+            if runInSubprocess:
+                from peek_platform.subproc_plugin_init.plugin_subproc_parent_main import (
+                    PluginSubprocParentMain,
+                )
+
+                EntryHookClass = PluginSubprocParentMain
+
+            else:
+                EntryHookClass = RealEntryHookClass
+
             ### Perform the loading of the plugin
             yield self._loadPluginThrows(
                 pluginName,
@@ -189,6 +225,10 @@ class PluginLoaderABC(metaclass=ABCMeta):
                 tuple(pluginRequiresService),
             )
 
+            yield self._setupStaticWebResourcesForPlugin(
+                RealEntryHookClass, pluginName
+            )
+
             # Make sure the version we have recorded is correct
             # JJC Disabled, this is just spamming the config file at the moment
             # PeekPlatformConfig.config.setPluginVersion(pluginName, pluginVersion)
@@ -227,6 +267,20 @@ class PluginLoaderABC(metaclass=ABCMeta):
 
         """
 
+    @inlineCallbacks
+    def _setupStaticWebResourcesForPlugin(
+        self, RealEntryHookClass, pluginName: str
+    ):
+        """Setup Static Web Resources For Plugin
+
+        If this is running in a subprocess, we need to call this method on the
+        actual plugin, not PluginSubprocParentMain
+        """
+        loadedPlugin = self._loadedPlugins[pluginName]
+
+        yield RealEntryHookClass.setupStaticWebResources(loadedPlugin._platform)
+
+    @inlineCallbacks
     def unloadPlugin(self, pluginName: str):
         oldLoadedPlugin = self._loadedPlugins.get(pluginName)
 
@@ -246,7 +300,7 @@ class PluginLoaderABC(metaclass=ABCMeta):
         )
         del self._vortexTupleNamesByPluginName[pluginName]
 
-        self._unloadPluginPackage(pluginName)
+        yield self._unloadPluginPackage(pluginName)
 
     def listPlugins(self):
         def pluginTest(name):
@@ -330,13 +384,33 @@ class PluginLoaderABC(metaclass=ABCMeta):
             logger.debug(remainingOptionalPlugins)
             raise Exception("Some plugins are still loaded")
 
+    # ---------------
+    # Standalone Plugins
+
+    @inlineCallbacks
+    def loadStandalonePlugin(self, pluginName: str):
+        yield self.loadPlugin(pluginName)
+
+    @inlineCallbacks
+    def startStandalonePlugin(self, pluginName: str):
+        yield self._tryStart(pluginName)
+
+    @inlineCallbacks
+    def stopStandalonePlugin(self, pluginName: str):
+        yield self._tryStop(pluginName)
+
+    @inlineCallbacks
+    def unloadStandalonePlugin(self, pluginName: str):
+        yield self.unloadPlugin(pluginName)
+
     # ---------------
     # Util methods Plugins
 
+    @inlineCallbacks
     def _tryStart(self, pluginName):
         plugin = self._loadedPlugins[pluginName]
         try:
-            return plugin.start()
+            yield plugin.start()
 
         except Exception as e:
             logger.error(
@@ -345,10 +419,11 @@ class PluginLoaderABC(metaclass=ABCMeta):
             )
             logger.exception(e)
 
+    @inlineCallbacks
     def _tryStop(self, pluginName):
         plugin = self._loadedPlugins[pluginName]
         try:
-            return plugin.stop()
+            yield plugin.stop()
 
         except Exception as e:
             logger.error(
@@ -357,6 +432,7 @@ class PluginLoaderABC(metaclass=ABCMeta):
             )
             logger.exception(e)
 
+    @inlineCallbacks
     def _unloadPluginPackage(self, pluginName):
 
         oldLoadedPlugin = self._loadedPlugins.get(pluginName)
@@ -365,7 +441,7 @@ class PluginLoaderABC(metaclass=ABCMeta):
         del self._loadedPlugins[pluginName]
 
         try:
-            oldLoadedPlugin.unload()
+            yield oldLoadedPlugin.unload()
 
         except Exception as e:
             logger.error(
